Check for constant variables
check_constant_vars.RdIdentifies variables that contain exactly one distinct non-missing value. Values defined as missing in the metadata are excluded from the check.

check_constant_vars.RdIdentifies variables that contain exactly one distinct non-missing value. Values defined as missing in the metadata are excluded from the check.